@@ -7,7 +7,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.010007";
+    our $MITE_VERSION = "0.011000";
 
     # Mite keywords
     BEGIN {
@@ -46,10 +46,12 @@
         *false   = \&Mite::Shim::false;
         *guard   = \&Mite::Shim::guard;
         *lazy    = \&Mite::Shim::lazy;
+        *lock    = \&Mite::Shim::lock;
         *ro      = \&Mite::Shim::ro;
         *rw      = \&Mite::Shim::rw;
         *rwp     = \&Mite::Shim::rwp;
         *true    = \&Mite::Shim::true;
+        *unlock  = \&Mite::Shim::unlock;
     }
 
     # Gather metadata for constructor and destructor
@@ -360,6 +362,11 @@
         our %DOES;
         return $DOES{$role} if exists $DOES{$role};
         return 1            if $role eq __PACKAGE__;
+        if ( $INC{'Moose/Util.pm'}
+            and my $meta = Moose::Util::find_meta( ref $self or $self ) )
+        {
+            $meta->can('does_role') and $meta->does_role($role) and return 1;
+        }
         return $self->SUPER::DOES($role);
     }
 
@@ -370,4 +377,3 @@
 
     1;
 }
-
